/*
*********************************************************************************************************
*                                               uC/OS-II
*                                         The Real-Time Kernel
*
*                         (c) Copyright 1998, Jean J. Labrosse, Plantation, FL
*                                          All Rights Reserved
*
*
*                                          9S12C32 Sample code
*
* 
* R.C. Maher
*********************************************************************************************************
*/
#include <hidef.h>      /* common defines and macros */
#include <mc9s12c32.h>     /* derivative information */
#include "INCLUDES.H"


#pragma LINK_INFO DERIVATIVE "mc9s12c32"

#define TASK_STK_SIZE 128

static void AppTickInit(void);

/* Declare storage for task stack(s) */
OS_STK taskstack1[TASK_STK_SIZE];


static void myTask1(void *pdata) {
/*
 * A task to flash LED 1 on the CSM daughterboard.
 */  
  pdata=pdata;

      while (TRUE) { /* Task body, always written as an infinite loop.          */
        OSTimeDlyHMSM(0,0,2,0);	 /* sleep for a while... */
        PORTA_BIT0 ^= 1;         /* toggle LED 1         */       
      }
}


/*
*********************************************************************************************************
*                                                main()
*
* Description : This is the standard entry point for C code.  It is assumed that your code will call
*               main() once you have performed all necessary 68HC12 and C initialization.
* Arguments   : none
*********************************************************************************************************
*/

void main(void) {

/* Initialize register and data direction bits     */  
    DDRA_BIT0 = 1;      /* set Port A  0 as output CSM LED 1 */
    DDRB_BIT4 = 1;			/* set Port B  4 as output CSM LED 2 */
    DDRAD_DDRAD4 = 1;		/* set Port AD 4 as output SLK LED 1 */
    DDRAD_DDRAD5 = 1;		/* set Port AD 5 as output SLK LED 2 */
    DDRT_DDRT4= 1;		  /* set Port T  4 as output SLK LED enable */
    
    PTT_PTT4 = 0;				/* Port T 4 (PTT4) low to enable SLK LEDs */

      
    OSInit();     /* Initialize "uC/OS-II, The Real-Time Kernel"             */
    AppTickInit();  

/*---- Any initialization code before starting multitasking ---------------------------------------*/

    OSTaskCreate(myTask1,(void *)0,&taskstack1[TASK_STK_SIZE-1],5);

/*---- Create any other task you want before we start multitasking --------------------------------*/

    EnableInterrupts;  

    OSStart();    /* Start multitasking (i.e. give control to uC/OS-II)      */

  
  /* Should NOT get here... */
    for(;;);

} /* end of main() */


static void AppTickInit (void)
{
   TSCR1   = 0x80;                    /* Enable timer*/
        
#if OS_TICK_OC == 0
    TIOS  |= 0x01;                    /* Make channel an output compare                          */
    TC0    = TCNT + OS_TICK_OC_CNTS;  /* Set TC0 to present time + OS_TICK_OC_CNTS               */
    TCTL1  |= 0x01;	              		/* set timer control reg */
    TIE |= 0x01;                      /* Enable OC0 interrupt.                                   */
#endif

#if OS_TICK_OC == 1 
    TIOS  |= 0x02;                    /* Make channel an output compare                          */
    TC1    = TCNT + OS_TICK_OC_CNTS;  /* Set TC1 to present time + OS_TICK_OC_CNTS               */
    TCTL1  |= 0x02;	              		/* set timer control reg */
    TIE |= 0x02;                      /* Enable OC1 interrupt.                                   */
#endif

#if OS_TICK_OC == 2
    TIOS  |= 0x04;                    /* Make channel an output compare                          */
    TC2    = TCNT + OS_TICK_OC_CNTS;  /* Set TC2 to present time + OS_TICK_OC_CNTS               */
    TCTL1  |= 0x04;	              	  /* set timer control reg */
    TIE |= 0x04;                      /* Enable OC2 interrupt.                                   */
#endif

#if OS_TICK_OC == 3
    TIOS  |= 0x08;                    /* Make channel an output compare                          */
    TC3    = TCNT + OS_TICK_OC_CNTS;  /* Set TC3 to present time + OS_TICK_OC_CNTS               */
    TCTL1  |= 0x08;	              		/* set timer control reg */
    TIE |= 0x08;                      /* Enable OC3 interrupt.                                   */
#endif

#if OS_TICK_OC == 4
    TIOS  |= 0x10;                    /* Make channel an output compare                          */
    TC4    = TCNT + OS_TICK_OC_CNTS;  /* Set TC4 to present time + OS_TICK_OC_CNTS               */
    TCTL1  |= 0x10;	              		/* set timer control reg */
    TIE |= 0x10;                      /* Enable OC4 interrupt.                                   */
#endif

#if OS_TICK_OC == 5
    TIOS  |= 0x20;                    /* Make channel an output compare                          */
    TC5    = TCNT + OS_TICK_OC_CNTS;  /* Set TC5 to present time + OS_TICK_OC_CNTS               */
    TCTL1  |= 0x20;	              	  /* set timer control reg */
    TIE |= 0x20;                      /* Enable OC5 interrupt.                                   */
#endif

#if OS_TICK_OC == 6
    TIOS  |= 0x40;                    /* Make channel an output compare                          */
    TC6    = TCNT + OS_TICK_OC_CNTS;  /* Set TC6 to present time + OS_TICK_OC_CNTS */
    TCTL1  |= 0x40;	              		/* set timer control reg */
    TIE |= 0x40;                      /* Enable OC6 interrupt.                                   */
#endif

#if OS_TICK_OC == 7
    TIOS  |= 0x80;                    /* Make channel an output compare                          */
    TC7    = TCNT + OS_TICK_OC_CNTS;  /* Set TC7 to present time + OS_TICK_OC_CNTS */
    TCTL1  |= 0x80;							      /* set timer control reg */
    TIE |= 0x80;                      /* Enable OC7 interrupt. */
   								                             
#endif
}

/* end of file */